# -*- coding: utf-8 -*-

from rest_framework import serializers

from .. import models


class CategorySerializer(serializers.ModelSerializer):
    class Meta:
        model = models.ProductCategory
        fields = '__all__'


class CategorySerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.ProductCategory
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class CategorySerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.ProductCategory
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class UnitTypeSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.UnitType
        fields = '__all__'


class UnitTypeSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.UnitType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class UnitTypeSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.UnitType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class MediaSerializer(serializers.ModelSerializer):
    small_image = serializers.SerializerMethodField()
    big_image = serializers.SerializerMethodField()

    class Meta:
        model = models.Media
        fields = '__all__'

    def get_small_image(self, obj):
        return obj.get_thumbnail(300, 300)

    def get_big_image(self, obj):
        return obj.get_thumbnail(600, 600)


class MediaSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.Media
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class MediaSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.Media
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class ProductSerializer(serializers.ModelSerializer):
    medias = MediaSerializer(many=True, read_only=True)
    categories = CategorySerializer(many=True, read_only=True)
    first_media_url = serializers.SerializerMethodField()
    price = serializers.SerializerMethodField()
    small_image = serializers.SerializerMethodField()
    big_image = serializers.SerializerMethodField()

    class Meta:
        model = models.Product
        fields = '__all__'

    def get_first_media_url(self, obj):
        return obj.get_first_media().get_url() if obj.get_first_media() else None

    def get_price(self, obj):
        return obj.get_price_vat_included()

    def get_small_image(self, obj):
        if obj.get_first_media():
            return obj.get_first_media().get_thumbnail(300, 300)

    def get_big_image(self, obj):
        if obj.get_first_media():
            return obj.get_first_media().get_thumbnail(600, 600)


class ProductSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.Product
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class ProductSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.Product
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
