# -*- coding: utf-8 -*-

from rest_framework import generics

from thux.api.views import QuerysetMixin
from thux.api.permissions import ThuxModelPermissions

from .. import models
from . import serializers


class CategoryList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ProductCategory.objects.all()
    serializer_class = serializers.CategorySerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(CategoryList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class CategoryRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ProductCategory.objects.all()
    serializer_class = serializers.CategorySerializer


class CategoryCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ProductCategory.objects.all()
    serializer_class = serializers.CategorySerializerCreate


class CategoryUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ProductCategory.objects.all()
    serializer_class = serializers.CategorySerializerUpdate


class UnitTypeList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.UnitType.objects.all()
    serializer_class = serializers.UnitTypeSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(UnitTypeList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class UnitTypeRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.UnitType.objects.all()
    serializer_class = serializers.UnitTypeSerializer


class UnitTypeCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.UnitType.objects.all()
    serializer_class = serializers.UnitTypeSerializerCreate


class UnitTypeUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.UnitType.objects.all()
    serializer_class = serializers.UnitTypeSerializerUpdate


class ProductList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Product.objects.all()
    serializer_class = serializers.ProductSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(ProductList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class ProductRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Product.objects.all()
    serializer_class = serializers.ProductSerializer


class ProductCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Product.objects.all()
    serializer_class = serializers.ProductSerializerCreate


class ProductUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Product.objects.all()
    serializer_class = serializers.ProductSerializerUpdate


class MediaList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Media.objects.all()
    serializer_class = serializers.MediaSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(MediaList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class MediaRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Media.objects.all()
    serializer_class = serializers.MediaSerializer
    lookup_field = 'slug'


class MediaCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Media.objects.all()
    serializer_class = serializers.MediaSerializerCreate


class MediaUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Media.objects.all()
    serializer_class = serializers.MediaSerializerUpdate
    lookup_field = 'slug'
