# -*- coding: utf-8 -*-

from rest_framework import serializers

from .. import models


class CategorySerializer(serializers.ModelSerializer):
    class Meta:
        model = models.ProductCategory
        fields = '__all__'


class UnitTypeSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.UnitType
        fields = '__all__'


class MediaSerializer(serializers.ModelSerializer):
    small_image = serializers.SerializerMethodField()
    big_image = serializers.SerializerMethodField()
    type = serializers.SerializerMethodField()
    url = serializers.SerializerMethodField()

    class Meta:
        model = models.Media
        fields = '__all__'

    def get_small_image(self, obj):
        return obj.get_thumbnail(300, 300)

    def get_big_image(self, obj):
        return obj.get_thumbnail(600, 600)

    def get_url(self, obj):
        return obj.get_thumbnail(600, 600)

    def get_type(self, obj):
        return 'image'


class ProductSerializer(serializers.ModelSerializer):
    categories = CategorySerializer(many=True, read_only=True)
    first_media_url = serializers.SerializerMethodField()
    price = serializers.SerializerMethodField()
    small_image = serializers.SerializerMethodField()
    big_image = serializers.SerializerMethodField()

    class Meta:
        model = models.Product
        fields = '__all__'

    def get_first_media_url(self, obj):
        return obj.get_first_media().get_url() if obj.get_first_media() else None

    def get_price(self, obj):
        return obj.get_price_vat_included()

    def get_small_image(self, obj):
        if obj.get_first_media():
            return obj.get_first_media().get_thumbnail(300, 300)

    def get_big_image(self, obj):
        if obj.get_first_media():
            return obj.get_first_media().get_thumbnail(600, 600)


class ProductColorSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.ProductColor
        fields = '__all__'


class ProductSizeSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.ProductSize
        fields = '__all__'
