# -*- coding: utf-8 -*-

from rest_framework import generics
from rest_framework.permissions import AllowAny

from thux.api.views import QuerysetMixin

from .. import models
from . import serializers


class CategoryList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    queryset = models.ProductCategory.objects.all()
    serializer_class = serializers.CategorySerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(CategoryList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class UnitTypeList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    queryset = models.UnitType.objects.all()
    serializer_class = serializers.UnitTypeSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(UnitTypeList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class ProductList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    queryset = models.Product.objects.filter(status=1)
    serializer_class = serializers.ProductSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(ProductList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class ProductRetrieve(generics.RetrieveAPIView):
    permission_classes = (AllowAny,)
    queryset = models.Product.objects.filter(status=1)
    serializer_class = serializers.ProductSerializer
    lookup_field = 'slug'


class MediaList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    queryset = models.Media.objects.all()
    serializer_class = serializers.MediaSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(MediaList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class ProductColorList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    queryset = models.ProductColor.objects.filter(status=1)
    serializer_class = serializers.ProductColorSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(ProductColorList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class ProductSizeList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    queryset = models.ProductSize.objects.filter(status=1)
    serializer_class = serializers.ProductSizeSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(ProductSizeList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset
